==> minitube_0.9.orig.tar.gz: minitube/locale/ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Webブラウザなしでも大丈夫!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>このプログラムは&quot;テクノロジープレビュー&quot;です。完璧な動作は期待しないでください。</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>バグレポートやアイデアは%1までお願いします</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1はフリーソフトウェアですが、開発には貴重な時間が費やされています。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>%2の開発/サポートのため、&lt;a href=&apos;%1&apos;&gt;寄付&lt;/a&gt;をお願いします。</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>アイコンは%1さんのデザインです。</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>コンパクトモードは%1さんの貢献です。</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>翻訳は%1さん達の協力です</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;で配布されます</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>プログラムについて</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>%1について知りたいことがあったら、思いきって連絡をください</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>検索中...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>さらに%1エントリ観る</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>見つかりませんでした</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>戻る(&amp;B)</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>前のビューに戻る</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>ストップ(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>再生を停止させて、検索ビューに戻ります</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>スキップ(&amp;k)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>次の動画へ</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>再生を一時停止します</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>フルスクリーン(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>フルスクリーン</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>コンパクトモード(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>プレイリストとツールバーを隠す</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>YouTube(&amp;Y)</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>YouTubeの動画Webページを開く</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>削除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>プレイリストから選択した動画を削除</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で上へ移動させます</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で下へ移動させます</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>プログラムを終了</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Webページへ(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1のWebページを開きます</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>寄付(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1の開発をサポートしてください！</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>プログラムについて(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl-M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished">アプリケーション(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>プレイリスト(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>動画(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1を開いています</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>致命的なエラー: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>エラー: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>再生再開します</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>フルスクリーンから戻る(&amp;F)</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>ボリューム%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>音量OFFにしました</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>音量ONにしました</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">検索</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>関連度</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>新着</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>閲覧回数</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>&quot;%1&quot;を閲覧中</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>ネットワークエラー: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1回 閲覧</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ようこそ&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;へ！</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>探している動画のキーワードを入力。</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近検索したキーワード</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>新しい%1があります。&lt;a href=&apos;%2&apos;&gt;バージョン%3へバージョンアップ&lt;/a&gt;しましょう</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>さあリラックスしましょう</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">閉じる(&amp;C)</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>ネットワークエラー: %1 (%2へのアクセスにて)</translation>
    </message>
</context>
</TS>

==> minitube_1.1.orig.tar.gz: minitube/locale/ja_JP.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Webブラウザなしでも大丈夫!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>バージョン %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">このプログラムは&quot;テクノロジープレビュー&quot;です。完璧な動作は期待しないでください。</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>バグレポートやアイデアは%1までお願いします</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1はフリーソフトウェアですが、開発には貴重な時間が費やされています。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">%2の開発/サポートのため、&lt;a href=&apos;%1&apos;&gt;寄付&lt;/a&gt;をお願いします。</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>アイコンは%1さんのデザインです。</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>コンパクトモードは%1さんの貢献です。</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>翻訳は%1さん達の協力です</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;で配布されます</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>プログラムについて</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>%1について知りたいことがあったら、思いきって連絡をください</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>検索中...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>さらに%1エントリ観る</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>見つかりませんでした</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>見つかりませんでした</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">戻る(&amp;B)</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">前のビューに戻る</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>ストップ(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>再生を停止させて、検索ビューに戻ります</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>スキップ(&amp;k)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>次の動画へ</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>一時停止(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>再生を一時停止します</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>フルスクリーン(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>フルスクリーン</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>コンパクトモード(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>プレイリストとツールバーを隠す</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">YouTube(&amp;Y)</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">YouTubeの動画Webページを開く</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>削除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>プレイリストから選択した動画を削除</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>上へ(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で上へ移動させます</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>下へ(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>選択した動画をプレイリスト内で下へ移動させます</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>終了(&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>プログラムを終了</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Webページへ(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1のWebページを開きます</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">寄付(&amp;D)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>%1の開発をサポートしてください！</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>プログラムについて(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl-M</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="unfinished">アプリケーション(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>プレイリスト(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>動画(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1を開いています</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>致命的なエラー: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>エラー: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>再生(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>再生再開します</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>フルスクリーンから戻る(&amp;F)</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>ボリューム%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>音量OFFにしました</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>音量ONにしました</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished">検索</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>関連度</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>新着</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>閲覧回数</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>&quot;%1&quot;を閲覧中</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>ネットワークエラー: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1回 閲覧</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>ようこそ&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;へ！</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>探している動画のキーワードを入力。</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近検索したキーワード</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>新しい%1があります。&lt;a href=&apos;%2&apos;&gt;バージョン%3へバージョンアップ&lt;/a&gt;しましょう</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>さあリラックスしましょう</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">設定</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">閉じる(&amp;C)</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>ネットワークエラー: %1 (%2へのアクセスにて)</translation>
    </message>
</context>
</TS>
